<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU">
<context>
    <name>ClipGrab</name>
    <message>
        <location filename="clipgrab.cpp" line="37"/>
        <source>Automatic language recognition</source>
        <translation>Automatikus nyelvfelismerés</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="514"/>
        <source>Downloading update … %1/%2 MBytes</source>
        <translation>Frissítés letöltése … %1/%2 MByte</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="523"/>
        <source>There was an error while downloading the update.: %1</source>
        <translation>Hiba történt a frissítés letöltése közben.: %1</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="537"/>
        <source>The fingerprint of the downloaded update file could not be verified: %1 should have been %2</source>
        <translation>Nem hitelesíthető a letöltött frissítés ellenörzőösszege: %1 helyett %2 kéne hogy legyen</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="549"/>
        <source>Could not open update file.</source>
        <translation>Nem nyitható meg a frissítés.</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <location filename="login_dialog.ui" line="20"/>
        <source>Confirmation or Login Required</source>
        <translation>Jóváhagyás vagy bejelentkezés szükséges</translation>
    </message>
    <message>
        <location filename="login_dialog.ui" line="54"/>
        <source>Confirmation or login required</source>
        <translation>Jóváhagyás vagy bejelentkezés szükséges</translation>
    </message>
    <message>
        <location filename="login_dialog.ui" line="67"/>
        <source>This video requires you to sign in or confirm your access before downloading it.</source>
        <translation>Ennek a videónak a letöltéséhez be kell jelentkezned, vagy jóvá kell hagynod a hozzáférést.</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location filename="login_dialog.ui" line="93"/>
        <source>Remember login</source>
        <translation>Emlékezzen rám</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="253"/>
        <source>Select Target</source>
        <translation>Mentés helyének kijelölése</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>Please wait while ClipGrab is loading information about the video ...</source>
        <translation>Kérlek várj, míg a ClipGrab kielemzi a videót...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="350"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation>Kezdéshez illeszd be a letölteni kívánt videó hivatkozását!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="355"/>
        <source>The link you have entered seems to not be recognised by any of the supported portals.&lt;br/&gt;Now ClipGrab will check if it can download a video from that site anyway.</source>
        <translation>A megadott hivatkozás nem felismerhető, vagy nem támogatott.&lt;br/&gt;Now ClipGrab will check if it can download a video from that site anyway.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="402"/>
        <source>No downloadable video could be found.&lt;br /&gt;Maybe you have entered the wrong link or there is a problem with your connection.</source>
        <translation>Nem található letölthető tartalom.&lt;br /&gt;A hivatkozás hibás lehet, vagy probléma merült fel az internetkapcsolatodban.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="415"/>
        <source>ClipGrab - Select target path</source>
        <translation>ClipGrab - Mentés helyének kijelölése</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="460"/>
        <source>ClipGrab: Video discovered in your clipboard</source>
        <translation>ClipGrab: Videó észlelve a vágólapon</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="460"/>
        <source>ClipGrab has discovered the address of a compatible video in your clipboard. Click on this message to download it now.</source>
        <translation>A ClipGrab felismert a vágólapon egy hivatkozását. Kattints erre az üzenetre a letöltés azonnali megkezdéséhez!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="566"/>
        <source>ClipGrab - Exit confirmation</source>
        <translation>ClipGrab - Kilépés megerősítése</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="566"/>
        <source>There is still at least one download in progress.&lt;br /&gt;If you exit the program now, all downloads will be canceled and cannot be recovered later.&lt;br /&gt;Do you really want to quit ClipGrab now?</source>
        <translation>Egy, vagy több művelet folyamatban van.&lt;br /&gt;Ha most kilépsz minden művelet megszakad végleg és nem lesz folytatható.&lt;br /&gt;Biztos vagy benne, hogy kilépsz a ClipGrab-ből?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Download finished</source>
        <translation>Letöltés befejeződött</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Downloading and converting “%title” is now finished.</source>
        <translation>A(z) “%title” letöltése és átalakítása befejeződött.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="607"/>
        <source>All downloads finished</source>
        <translation>Minden letöltés befejeződött</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="607"/>
        <source>ClipGrab has finished downloading and converting all selected videos.</source>
        <translation>A ClipGrab minden listán szereplő műveletet befejezett.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="672"/>
        <location filename="mainwindow.cpp" line="674"/>
        <location filename="mainwindow.cpp" line="681"/>
        <location filename="mainwindow.cpp" line="683"/>
        <source>ClipGrab</source>
        <translation>ClipGrab</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="672"/>
        <location filename="mainwindow.cpp" line="674"/>
        <source> MiB</source>
        <translation> MB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="674"/>
        <source> KiB</source>
        <translation> KB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="681"/>
        <location filename="mainwindow.cpp" line="683"/>
        <source>Currently no downloads in progress.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="684"/>
        <source>ClipGrab - Download and Convert Online Videos</source>
        <translation>ClipGrab - Internetes videók letöltése és átalakítása</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="846"/>
        <source>No results found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="913"/>
        <source>&amp;Open downloaded file</source>
        <translation>Letöltött fájl megnyitása (&amp;o)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="914"/>
        <source>Open &amp;target folder</source>
        <translation>Célkönyv&amp;tár megnyitása</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="916"/>
        <source>&amp;Pause download</source>
        <translation>Letöltés szüneteltetése (&amp;p)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="917"/>
        <source>&amp;Restart download</source>
        <translation>Letöltés új&amp;raindítása</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="918"/>
        <source>&amp;Cancel download</source>
        <translation>Letöltés megszakítása (&amp;c)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="920"/>
        <source>Copy &amp;video link</source>
        <translation>&amp;Videó linkjének másolása</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="921"/>
        <source>Open video link in &amp;browser</source>
        <translation>Videó megnyitása a &amp;böngészőben</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="926"/>
        <source>Resume download</source>
        <translation>Letöltés folytatása</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="936"/>
        <source>Show in &amp;Finder</source>
        <translation>Megjelenítés a keresőben (&amp;f)</translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>ClipGrab - Download and Convert Online Videos</source>
        <translation>ClipGrab - Internetes videók letöltése és átalakítása</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="152"/>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="171"/>
        <source>Enter keywords in the box below in order to search videos on YouTube</source>
        <translation>Írj be kulcsszavakat YouTube-on való kereséshez!</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="189"/>
        <source>Downloads</source>
        <translation>Letöltés</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="198"/>
        <source>Grab this clip!</source>
        <translation>Letöltés</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="227"/>
        <source>Quality:</source>
        <translation>Minőség:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="243"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation>Másold be a letölteni kívánt videó hivatkozását!</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="278"/>
        <source>Format:</source>
        <translation>Formátum:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="317"/>
        <source>Current Downloads:</source>
        <translation>Folyamatban lévő letöltések:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="327"/>
        <source>Cancel selected download</source>
        <translation>Kijelölt letöltések megszakítása</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="337"/>
        <source>Open the target folder of the selected download</source>
        <translation>Célkönyvtár megnyitása</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="357"/>
        <source>Portal</source>
        <translation>Forrás</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="362"/>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="367"/>
        <source>Format</source>
        <translation>Formátum</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="372"/>
        <source>Progress</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="383"/>
        <source>Pause selected download</source>
        <translation>Kijelölt letöltések szüneteltetése</translation>
    </message>
    <message>
        <source>…</source>
        <translation type="obsolete">…</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="395"/>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="408"/>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="432"/>
        <source>Here you can adjust some general settings concerning the behaviour of ClipGrab.</source>
        <translation>Itt módosíthatod a ClipGrab alapvető beállításait</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="443"/>
        <source>Target Path</source>
        <translation>Mentés helye</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="449"/>
        <source>Always save at the last used path.</source>
        <translation>Utoljára használt könyvtár megjegyzése</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="463"/>
        <source>Here you can configure where the downloaded videos are to be saved.</source>
        <translation>Itt adhatod meg, hogy hova mentse a program a letöltött videókat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="470"/>
        <source>Browse ...</source>
        <translation>Tallózás...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="477"/>
        <source>Never ask for file name</source>
        <translation>Fájl automatikus elnevezése</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="498"/>
        <source>Metadata</source>
        <translation>Metaadat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="504"/>
        <source>Here you can configure if ClipGrab is supposed to add metadata (ID3 tags) to your mp3 files.</source>
        <translation>Itt állíthatod be, hogy ClipGrab mellékeljen-e metaadatokat (ID3-címkét) a letöltött mp3 formátumú fájlokhoz</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="511"/>
        <source>Use metadata</source>
        <translation>Metaadat írása</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="532"/>
        <source>Clipboard</source>
        <translation>Vágólap</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="538"/>
        <source>Here you can configure how ClipGrab behaves when a downloadable video is discovered in your clipboard.</source>
        <translation>Itt állíthatod be, hogy a ClipGrab hogyan kezelje a vágólapon lévő hivatkozásokat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="545"/>
        <source>Always download</source>
        <translation>Azonnali letöltés</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="552"/>
        <source>Never download</source>
        <translation>Ne töltse le</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="559"/>
        <source>Always ask</source>
        <translation>Kérdezzen meg</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="580"/>
        <source>Notifications</source>
        <translation>Értesítések</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="586"/>
        <source>After each download</source>
        <translation>Minden egyes letöltés után</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="593"/>
        <source>After all downloads have been completed</source>
        <translation>Minden letöltés befejezése után</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="613"/>
        <source>Here you can configure when ClipGrab is supposed to display notifications.</source>
        <translation>Itt állíthatod be, hogy hogyan értesítsen a ClipGrab a letöltésekről</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="620"/>
        <source>Never</source>
        <translation>Soha</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="628"/>
        <source>Proxy</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="634"/>
        <source>Use a proxy server</source>
        <translation>Proxy-szerver használata</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="644"/>
        <source>Proxy settings</source>
        <translation>Proxy beállításai</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="653"/>
        <source>Hostname/IP:</source>
        <translation>KIszolgáló:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="660"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="687"/>
        <source>Proxy type:</source>
        <translation>Proxy típusa:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="695"/>
        <source>HTTP Proxy</source>
        <translation>HTTP proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="700"/>
        <source>Socks5 Proxy</source>
        <translation>Socks5 proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="727"/>
        <source>Proxy authentication</source>
        <translation>Hitelesítési adatok</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="733"/>
        <source>Username:</source>
        <translation>Felhasználónév:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="750"/>
        <source>Password:</source>
        <translation>Jelszó:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="763"/>
        <source>Proxy requires authentication</source>
        <translation>Hitelesítés használata</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="771"/>
        <source>Other</source>
        <translation>Egyéb</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="798"/>
        <source>Remove finished downloads from list</source>
        <translation>Befejezett letöltések eltávolítása a listáról</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="777"/>
        <source>Minimize ClipGrab to the system tray</source>
        <translation>ClipGrab küldése tálcára kicsinyítéskor</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="784"/>
        <source>Use WebM if possible</source>
        <translation>WebM formátum használata amikor csak lehetséges</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="791"/>
        <source>Ignore SSL errors</source>
        <translation>SSL hibák figyelmen kívül hagyása</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="818"/>
        <source>Remember logins</source>
        <translation>Emlékezzen a bejelentkezésekre</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="825"/>
        <source>Remember video quality</source>
        <translation>Emlékezzen a videóminőségre</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="837"/>
        <source>Language</source>
        <translation>Nyelv</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="861"/>
        <source>Here you can change the language of ClipGrab.</source>
        <translation>Itt állíthatod be a ClipGrab felületének nyelvét.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="868"/>
        <source>Please select a language from the list below. You have to restart ClipGrab in order to apply you selection.</source>
        <translation>Kérlek, válassz nyelvet! A beállítás a program újraindítása után lép életbe.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="905"/>
        <source>Conversion</source>
        <translation>Átalakítás</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="928"/>
        <source>Experts can create custom presets for the video conversion here.</source>
        <translation>Hozzáértők itt állíthatnak be egyedi profilokat átalakításhoz.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="935"/>
        <source>Format preset</source>
        <translation>Átalakítási profil</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="945"/>
        <source>Add new preset</source>
        <translation>Profil létrehozása</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="952"/>
        <source>Remove selected preset</source>
        <translation>Profil törlése</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="975"/>
        <source>Audio</source>
        <translation>Hang</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="987"/>
        <location filename="mainwindow.ui" line="1039"/>
        <source>Codec</source>
        <translation>Kódoló</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1013"/>
        <location filename="mainwindow.ui" line="1101"/>
        <source>Bitrate (kb/s)</source>
        <translation>BItsűrűség (kb/s)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1020"/>
        <source>Disable Audio</source>
        <translation>Hang letiltása</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1030"/>
        <source>Video</source>
        <translation>Kép</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1052"/>
        <source>Frames/second</source>
        <translation>Képsebesség</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1111"/>
        <source>Disable video</source>
        <translation>Videó letiltása</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1126"/>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1132"/>
        <source>&lt;h2&gt;Support ClipGrab!&lt;/h2&gt;
&lt;p&gt;Only with your support, ClipGrab can remain free software!&lt;br&gt;So if you like ClipGrab and also want to help ensuring its further development, please consider making a donation.&lt;/p&gt;</source>
        <translation>&lt;h2&gt;Támogass!&lt;/h2&gt;
&lt;p&gt;A ClipGrab támogatásotokkal maradhat a jövőben is ingyenes.&lt;br&gt;Ha a program elnyerte tetszésetek, és szeretnétek biztosítani a fejlesztését, kérlek, adományozzatok!&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1175"/>
        <source>&lt;h2&gt;Translation&lt;/h2&gt;
ClipGrab is already available in many languages. If ClipGrab has not been translated into your language yet and if you want to contribute a translation, please check &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; for further information.</source>
        <translation>&lt;h2&gt;Fordítás&lt;/h2&gt;
A ClipGrab magyar fordítását karbantartja: Kádár Iván. Ha hibát találsz, kérlek, jelezd: &lt;a href=&quot;mailto:ivan.kadar (kukac) gmail.com?Subject=ClipGrab fordítás&quot;&gt;ivan.kadar (kukac) gmail.com&lt;/a&gt;
Ha más nyelvre szeretnéd lefordítani a programot, látogasd meg a &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; oldalt további tudnivalókért!</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1192"/>
        <source>&lt;h2&gt;Thanks&lt;/h2&gt;
ClipGrab relies on the work of the Qt project and the ffmpeg team.&lt;br&gt;
Visit &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt; and &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt; for further information.</source>
        <translation>&lt;h2&gt;Köszönet&lt;/h2&gt;
A ClipGrab a Qt-projekt és az ffmpeg fejlesztői csapatának munkáira épül.&lt;br&gt;
Látogasd meg a &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt; és a &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt; oldalakat további tudnivalókért!</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="metadata-dialog.ui" line="14"/>
        <source>ClipGrab - enter metadata</source>
        <translation>ClipGrab - címke megadása</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; font-weight:600;&quot;&gt;Please enter the metadata for your download. If you don&apos;t want to add&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; font-weight:600;&quot;&gt;metadata, just leave the fields empty.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; font-weight:600;&quot;&gt;Kérlek, töltsd ki a mezőket!&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; font-weight:600;&quot;&gt;Amennyiben nem szeretnéd, egyszerűen csak hagyd üresen.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="25"/>
        <source>Please enter the metadata for your download. If you don&apos;t want to add metadata, just leave the fields empty.</source>
        <translation>Kérlek, töltsd ki a metaadatokat a letöltéshez. Ha nem akarsz megadni metaadatokat, hagyd üresen a mezőket.</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="45"/>
        <source>Title:</source>
        <translation>Cím:</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="52"/>
        <source>Artist:</source>
        <translation>Előadó:</translation>
    </message>
</context>
<context>
    <name>UpdateMessage</name>
    <message>
        <location filename="update_message.ui" line="14"/>
        <source>Update for ClipGrab</source>
        <translation>ClipGrab frissítése</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="116"/>
        <source>ClipGrab %1 is now available (you are using %2). Would you like to install the update?</source>
        <translation>Elérhető Clipgrab verzió: %1 (telepített verzió: %2) Szeretnéd feltenni a frissítést?</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="130"/>
        <source>There is an update for your version of ClipGrab!</source>
        <translation>Eléhető egy frissítés a ClipGrab-hez!</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="64"/>
        <source>Skip this update</source>
        <translation>Frissítés kihagyása</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="91"/>
        <source>Download update</source>
        <translation>Frissítés letöltése</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="240"/>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="74"/>
        <source>Remind me later</source>
        <translation>Emlékeztessen később</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="41"/>
        <source>The update will begin in just a moment …</source>
        <translation>A frissítés pár pillanat múlva elkezdődik...</translation>
    </message>
</context>
<context>
    <name>YoutubePassword</name>
    <message>
        <source>Password required</source>
        <translation type="obsolete">Tartalommal kapcsolatos figyelmeztetés</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="obsolete">about:blank</translation>
    </message>
    <message>
        <source>This video has an age restriction or is only available for certain users.
Please login with your Google account in order to download this video.</source>
        <translation type="obsolete">Ez a videó egyesek számára kifogásolható lehet.
Kérlek, jelentkezz be Google-fiókoddal a tartalom letöltéséhez!</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="obsolete">Jelszó:</translation>
    </message>
    <message>
        <source>E-mail:</source>
        <translation type="obsolete">E-mail cím:</translation>
    </message>
    <message>
        <source>Save login data</source>
        <translation type="obsolete">Bejelentkezési adatok megjegyzése</translation>
    </message>
</context>
<context>
    <name>converter_copy</name>
    <message>
        <location filename="converter_copy.cpp" line="28"/>
        <source>Original</source>
        <translation>Eredeti formátum</translation>
    </message>
</context>
<context>
    <name>converter_ffmpeg</name>
    <message>
        <location filename="converter_ffmpeg.cpp" line="212"/>
        <source>MPEG4</source>
        <translation>MPEG4</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="213"/>
        <source>WMV (Windows)</source>
        <translation>WMV (Windows)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="214"/>
        <source>OGG Theora</source>
        <translation>OGG Theora</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="215"/>
        <source>MP3 (audio only)</source>
        <translation>MP3 (csak hang) </translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="216"/>
        <source>OGG Vorbis (audio only)</source>
        <translation>OGG Vorbis (csak hang) </translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="217"/>
        <source>Original (audio only)</source>
        <translation>Eredeti (csak hang)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="345"/>
        <source>No installed version of avconv or ffmpeg coud be found. Converting files and downloading 1080p videos from YouTube is not supported.</source>
        <translation>Nem található a rendszerben telepített avconv vagy ffmeg kódoló. Nagy felbontású videók letöltése így nem lehetséges.</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="360"/>
        <source>The installed version of %1 is outdated.
Downloading 1080p videos from YouTube is not supported.</source>
        <translation>A rendszerben található %1 verziója elavult.
Nagy felbontású videók letöltése így nem lehetséges.</translation>
    </message>
</context>
<context>
    <name>messageDialog</name>
    <message>
        <location filename="message_dialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Értesítés</translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="48"/>
        <source>Close this message</source>
        <translation>Üzenet bezárása</translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="71"/>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
</context>
<context>
    <name>playlistDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Értesítés</translation>
    </message>
    <message>
        <source>Grab those clips!</source>
        <translation type="obsolete">Letöltés</translation>
    </message>
    <message>
        <source>Here you can set up the download of multiple videos at once.</source>
        <translation type="obsolete">Itt tudsz egyszerre több videót letölteni.</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation type="obsolete">Összes kijelölése</translation>
    </message>
    <message>
        <source>Add link to list</source>
        <translation type="obsolete">Link hozzáadása a listához</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Mégse</translation>
    </message>
    <message>
        <source>Deselect all</source>
        <translation type="obsolete">Kijelölés megszüntetése</translation>
    </message>
</context>
<context>
    <name>video</name>
    <message>
        <location filename="video.cpp" line="157"/>
        <location filename="video.cpp" line="303"/>
        <source>Converting ...</source>
        <translation>Átalakítás...</translation>
    </message>
    <message>
        <location filename="video.cpp" line="198"/>
        <source>Downloading ...</source>
        <translation>Letöltés...</translation>
    </message>
    <message>
        <location filename="video.cpp" line="198"/>
        <source> MiB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="video.cpp" line="368"/>
        <source>Finished</source>
        <translation>Kész</translation>
    </message>
    <message>
        <location filename="video.cpp" line="374"/>
        <source>Finished!</source>
        <translation>Befejezve.</translation>
    </message>
    <message>
        <location filename="video.cpp" line="513"/>
        <source>Cancelled</source>
        <translation>Megszakítva</translation>
    </message>
</context>
<context>
    <name>video_clipfish</name>
    <message>
        <source>normal</source>
        <translation type="obsolete">Átlagos</translation>
    </message>
</context>
<context>
    <name>video_dailymotion</name>
    <message>
        <location filename="video_dailymotion.cpp" line="73"/>
        <source>HD (1080p)</source>
        <translation>Nagy felbontású (1080p)</translation>
    </message>
    <message>
        <location filename="video_dailymotion.cpp" line="74"/>
        <source>HD (720p)</source>
        <translation>Nagy felbontású (720)</translation>
    </message>
    <message>
        <location filename="video_dailymotion.cpp" line="75"/>
        <source>480p</source>
        <translation>480p</translation>
    </message>
    <message>
        <location filename="video_dailymotion.cpp" line="76"/>
        <source>380p</source>
        <translation>380p</translation>
    </message>
    <message>
        <location filename="video_dailymotion.cpp" line="77"/>
        <source>240p</source>
        <translation>240p</translation>
    </message>
    <message>
        <source>high (480p)</source>
        <translation type="obsolete">Átlagos (480p)</translation>
    </message>
    <message>
        <source>low (240p)</source>
        <translation type="obsolete">Alacsony (240p)</translation>
    </message>
</context>
<context>
    <name>video_facebook</name>
    <message>
        <location filename="video_facebook.cpp" line="161"/>
        <location filename="video_facebook.cpp" line="162"/>
        <location filename="video_facebook.cpp" line="191"/>
        <source>HD</source>
        <translation>Nagy felbontású</translation>
    </message>
    <message>
        <location filename="video_facebook.cpp" line="163"/>
        <location filename="video_facebook.cpp" line="164"/>
        <source>normal</source>
        <translation>normál minőség</translation>
    </message>
</context>
<context>
    <name>video_heuristic</name>
    <message>
        <location filename="video_heuristic.cpp" line="75"/>
        <location filename="video_heuristic.cpp" line="88"/>
        <location filename="video_heuristic.cpp" line="100"/>
        <location filename="video_heuristic.cpp" line="113"/>
        <location filename="video_heuristic.cpp" line="128"/>
        <location filename="video_heuristic.cpp" line="142"/>
        <location filename="video_heuristic.cpp" line="155"/>
        <location filename="video_heuristic.cpp" line="168"/>
        <location filename="video_heuristic.cpp" line="182"/>
        <source>normal</source>
        <translation>Átlagos</translation>
    </message>
</context>
<context>
    <name>video_myspass</name>
    <message>
        <location filename="video_myspass.cpp" line="87"/>
        <source>high</source>
        <translation>Magas</translation>
    </message>
</context>
<context>
    <name>video_myvideo</name>
    <message>
        <source>normal</source>
        <translation type="obsolete">Átlagos</translation>
    </message>
</context>
<context>
    <name>video_vimeo</name>
    <message>
        <source>HD</source>
        <translation type="obsolete">Nagy felbontású</translation>
    </message>
    <message>
        <source>high</source>
        <translation type="obsolete">Magas</translation>
    </message>
    <message>
        <source>low</source>
        <translation type="obsolete">Alacsony</translation>
    </message>
</context>
<context>
    <name>video_youtube</name>
    <message>
        <location filename="video_youtube.cpp" line="144"/>
        <source>HD (1080p)</source>
        <translation>HD (1080p)</translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="148"/>
        <source>HD (1440p)</source>
        <translation>HD (1440p)</translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="152"/>
        <source>4K (2160p)</source>
        <translation>4K (2160p)</translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="156"/>
        <source>5K (2880p)</source>
        <translation>5K (2880p)</translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="160"/>
        <source>8K (4320p)</source>
        <translation>8K (4320p)</translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="163"/>
        <source>8K (4320p60)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="481"/>
        <location filename="video_youtube.cpp" line="512"/>
        <location filename="video_youtube.cpp" line="611"/>
        <location filename="video_youtube.cpp" line="614"/>
        <source>Original</source>
        <translation>Eredeti minőség</translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="663"/>
        <source>normal</source>
        <translation>normál minőség</translation>
    </message>
</context>
</TS>
